==> spring-batch-core-4.3.3-sources.jar: org/springframework/batch/core/configuration/xml/StandaloneStepParser.java <==
/*
 * Copyright 2006-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.batch.core.configuration.xml;

import org.springframework.beans.factory.support.AbstractBeanDefinition;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

/**
 * Internal parser for the &lt;step/&gt; elements for a job. A step element
 * references a bean definition for a
 * {@link org.springframework.batch.core.Step}.
 * 
 * @author Dave Syer
 * @author Thomas Risberg
 * @since 2.0
 */
public class StandaloneStepParser extends AbstractStepParser {

	/**
	 * Parse the step and turn it into a list of transitions.
	 * 
	 * @param element the &lt;step/gt; element to parse
	 * @param parserContext the parser context for the bean factory
	 * @return {@link AbstractBeanDefinition} instance.
	 */
	public AbstractBeanDefinition parse(Element element, ParserContext parserContext) {
		return parseStep(element, parserContext, null);
	}
}

==> spring-batch-core-5.0.2-sources.jar: org/springframework/batch/core/configuration/xml/StandaloneStepParser.java <==
/*
 * Copyright 2006-2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.batch.core.configuration.xml;

import org.springframework.beans.factory.support.AbstractBeanDefinition;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

/**
 * Internal parser for the &lt;step/&gt; elements for a job. A step element references a
 * bean definition for a {@link org.springframework.batch.core.Step}.
 *
 * @author Dave Syer
 * @author Thomas Risberg
 * @since 2.0
 */
public class StandaloneStepParser extends AbstractStepParser {

	/**
	 * Parse the step and turn it into a list of transitions.
	 * @param element The &lt;step/gt; element to parse
	 * @param parserContext The parser context for the bean factory
	 * @return an {@link AbstractBeanDefinition} instance.
	 */
	public AbstractBeanDefinition parse(Element element, ParserContext parserContext) {
		return parseStep(element, parserContext, null);
	}

}
